/*!
    \file  monaTester.h
    \brief definition for tester

    definition for tester
    Copyright (c) 2002 HigePon
    WITHOUT ANY WARRANTY

    \author  HigePon
    \version $Revision: 1.8 $
    \date   create:2002/11/11 update:$Date: 2003/03/01 05:22:03 $
*/

#ifndef _MONA_TESTER_
#define _MONA_TESTER_

void hvectorTester();
void operatorTester();
void typeTester();
void processTester();
void process1Tester();
void process2Tester();
void process3Tester();
void STLTester();
#endif
